function categorizeRainfall(rainfall) {
  if (rainfall < 500) return '0-500';
  if (rainfall >= 500 && rainfall < 1000) return '500-1000';
  if (rainfall >= 1000 && rainfall < 1500)
    return '1000-1500';
  return '1500+';
}

// Load the dataset
d3.csv('rainfall_dataset.csv').then(function (data) {
  // Parse and transform data
  data.forEach(function (d) {
    d['Rain Fall (mm)'] = +d['Rain Fall (mm)'];
    d['Yield (Q/acre)'] = +d['Yield (Q/acre)'];
    d['Rainfall Category'] = categorizeRainfall(
      d['Rain Fall (mm)'],
    );
  });

  // Group data by Rainfall Category for bar chart
  let sumstat = d3
    .rollups(
      data,
      (v) => d3.mean(v, (d) => d['Yield (Q/acre)']),
      (d) => d['Rainfall Category'],
    )
    .sort((a, b) => d3.ascending(a[0], b[0]));

  // Set the dimensions for the bar chart
  const barMargin = {
      top: 20,
      right: 20,
      bottom: 30,
      left: 40,
    },
    barWidth = 500 - barMargin.left - barMargin.right,
    barHeight = 300 - barMargin.top - barMargin.bottom;

  const barSvg = d3
    .select('#barChart')
    .append('svg')
    .attr(
      'width',
      barWidth + barMargin.left + barMargin.right,
    )
    .attr(
      'height',
      barHeight + barMargin.top + barMargin.bottom,
    )
    .append('g')
    .attr(
      'transform',
      'translate(' +
        barMargin.left +
        ',' +
        barMargin.top +
        ')',
    );

  // Create the X-axis band scale
  const x = d3
    .scaleBand()
    .range([0, barWidth])
    .domain(data.map((d) => d['Rainfall Category']))
    .padding(0.1);

  // Add the X-axis to the bar chart
  barSvg
    .append('g')
    .attr('transform', 'translate(0,' + barHeight + ')')
    .call(d3.axisBottom(x))
    .selectAll('.tick text')
    .call(wrap, x.bandwidth()); // A hypothetical wrap function to handle text wrapping

  // Create the Y-axis linear scale
  const y = d3
    .scaleLinear()
    .domain([0, d3.max(sumstat, (d) => d[1])])
    .range([barHeight, 0]);

  // Add the Y-axis to the bar chart
  barSvg.append('g').call(d3.axisLeft(y));

  // Create bars for the bar chart
  barSvg
    .selectAll('.bar')
    .data(sumstat)
    .join('rect')
    .attr('class', 'bar')
    .attr('x', (d) => x(d[0]))
    .attr('y', (d) => y(d[1]))
    .attr('width', x.bandwidth())
    .attr('height', (d) => barHeight - y(d[1]));

  // Set the dimensions for the scatter plot
  const scatterMargin = {
      top: 20,
      right: 20,
      bottom: 30,
      left: 40,
    },
    scatterWidth =
      500 - scatterMargin.left - scatterMargin.right,
    scatterHeight =
      300 - scatterMargin.top - scatterMargin.bottom;

  // Create SVG for scatter plot
  const scatterSvg = d3
    .select('#scatterPlot')
    .append('svg')
    .attr(
      'width',
      scatterWidth +
        scatterMargin.left +
        scatterMargin.right,
    )
    .attr(
      'height',
      scatterHeight +
        scatterMargin.top +
        scatterMargin.bottom,
    )
    .append('g')
    .attr(
      'transform',
      'translate(' +
        scatterMargin.left +
        ',' +
        scatterMargin.top +
        ')',
    );

  // Create the X-axis linear scale for scatter plot
  const scatterX = d3
    .scaleLinear()
    .domain(d3.extent(data, (d) => d['Rain Fall (mm)']))
    .range([0, scatterWidth]);

  // Add the X-axis to the scatter plot
  scatterSvg
    .append('g')
    .attr('transform', 'translate(0,' + scatterHeight + ')')
    .call(d3.axisBottom(scatterX));

  // Create the Y-axis linear scale for scatter plot
  const scatterY = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d['Yield (Q/acre)'])])
    .range([scatterHeight, 0]);

  // Add the Y-axis to the scatter plot
  scatterSvg.append('g').call(d3.axisLeft(scatterY));

  // Create points for the scatter plot
  scatterSvg
    .selectAll('.scatter')
    .data(data)
    .join('circle')
    .attr('class', 'scatter')
    .attr('cx', (d) => scatterX(d['Rain Fall (mm)']))
    .attr('cy', (d) => scatterY(d['Yield (Q/acre)']))
    .attr('r', 5);
});
